==> kubernetes-model-core-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class PersistentVolumeClaimVolumeSourceFluentImpl<A extends PersistentVolumeClaimVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PersistentVolumeClaimVolumeSourceFluent<A> {

    private String claimName;
    private Boolean readOnly;

    public PersistentVolumeClaimVolumeSourceFluentImpl() { 
    }


    public PersistentVolumeClaimVolumeSourceFluentImpl(PersistentVolumeClaimVolumeSource instance) { 
        this.withClaimName(instance.getClaimName()); 
        this.withReadOnly(instance.getReadOnly()); 
    }


    public String getClaimName() {
        return this.claimName;
    }

    public A withClaimName(String claimName) {
        this.claimName=claimName; return (A) this;
    }

    public Boolean hasClaimName() {
        return this.claimName != null;
    }

    public A withNewClaimName(String arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(StringBuilder arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(StringBuffer arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public Boolean isReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PersistentVolumeClaimVolumeSourceFluentImpl that = (PersistentVolumeClaimVolumeSourceFluentImpl) o;
        if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(claimName,  readOnly,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class PersistentVolumeClaimVolumeSourceFluentImpl<A extends PersistentVolumeClaimVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PersistentVolumeClaimVolumeSourceFluent<A> {

    private String claimName;
    private Boolean readOnly;

    public PersistentVolumeClaimVolumeSourceFluentImpl() {
    }

    public PersistentVolumeClaimVolumeSourceFluentImpl(PersistentVolumeClaimVolumeSource instance) {
        this.withClaimName(instance.getClaimName()); 
        this.withReadOnly(instance.getReadOnly()); 
    }

    public String getClaimName() {
        return this.claimName;
    }

    public A withClaimName(String claimName) {
        this.claimName=claimName; return (A) this;
    }

    public Boolean hasClaimName() {
        return this.claimName != null;
    }

    public A withNewClaimName(StringBuilder arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(int[] arg1,int arg2,int arg3) {
        return (A)withClaimName(new String(arg1, arg2, arg3));
    }

    public A withNewClaimName(char[] arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(StringBuffer arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(byte[] arg1,int arg2) {
        return (A)withClaimName(new String(arg1, arg2));
    }

    public A withNewClaimName(byte[] arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(char[] arg1,int arg2,int arg3) {
        return (A)withClaimName(new String(arg1, arg2, arg3));
    }

    public A withNewClaimName(byte[] arg1,int arg2,int arg3) {
        return (A)withClaimName(new String(arg1, arg2, arg3));
    }

    public A withNewClaimName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withClaimName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewClaimName(String arg1) {
        return (A)withClaimName(new String(arg1));
    }

    public Boolean getReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PersistentVolumeClaimVolumeSourceFluentImpl that = (PersistentVolumeClaimVolumeSourceFluentImpl) o;
        if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(claimName,  readOnly,  super.hashCode());
    }

}
